#
# spec file for package intltool
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           intltool
Version:        0.51.0
Release:        8.3
Summary:        Internationalization Tool Collection
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://edge.launchpad.net/intltool/
Source:         https://launchpad.net/%{name}/trunk/%{version}/+download/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM intltool-perl-5.22.patch lp#1490906 dimstar@opensuse.org -- Fix execution with perl 5.22
Patch0:         intltool-perl-5.22.patch
# PATCH-FIX-UPSTREAM fixrace.patch lp#1687644 boo#1021335
Patch1:         fixrace.patch
# PATCH-FIX-UPSTREAM intltool-no-guess-builddir.patch lp#1117944 -- Fix out of tree builds with automake 1.15
Patch2:         intltool-no-guess-builddir.patch
BuildRequires:  perl(XML::Parser)
Requires:       gettext-tools
Requires:       perl(XML::Parser)
Provides:       xml-i18n-tools
Obsoletes:      xml-i18n-tools
BuildArch:      noarch

%description
Some scripts to support translators working on GNOME and similar
programs. Data available in XML files (.oaf, .desktop, .sheet, and
more) can be extracted into PO files. After translation, the new
information is written back into the XML files.

%prep
%autosetup -p1

%build
%configure
%make_build

%check
%make_build check

%install
%make_install

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%{_bindir}/intltool-*
%{_bindir}/intltoolize
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/intltool.m4
%{_datadir}/%{name}/
%{_mandir}/man8/intltool-*.8%{?ext_man}
%{_mandir}/man8/intltoolize.8%{?ext_man}

%changelog
* Sun Oct  8 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Rebase intltool-perl-5.22.patch, use autosetup and make_build
  macros.
- Replace perl-XML-Parser with perl(XML::Parser)
  BuildRequires/Requires: Be explicit about the symbol we need.
* Sun May 13 2018 bjorn.lie@gmail.com
- Add intltool-no-guess-builddir.patch: Fix out of tree builds with
  automake 1.15 and newer, patch taken from Ubuntu (lp#1117944).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Sep 24 2017 coolo@suse.com
- extend intltool-perl-5.22.patch to fix one more perl 5.26 issue
* Tue May  2 2017 bwiedemann@suse.com
- Add fixrace.patch to fix random desktop file corruptions
  (lp#1687644 boo#1021335)
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Sep  1 2015 dimstar@opensuse.org
- Add intltool-perl-5.22.patch: Fix execution with perl 5.22.
* Wed Mar 25 2015 zaitor@opensuse.org
- Update to version 0.51.0:
  + Don't write $SRCDIR to the pot file.
  + Fixed incorrect handling of spaces around = in .ini files.
  + Add support for QT designer .UI files.
  + Add missing files to Makefile.am EXTRA_DIST definitions.
  + Use plain localedir to install mo files to, rather than trying
    to guess one.
  + Fix makefile rule to build .pox files properly.
  + Fix incorrect usage of hyphens and dashes in man pages.
  + Update .bzrignore with some new generated files.
  + Use autoreconf instead of gnome-autogen scripts.
  + Remove obsolete AM_GNU_GETTEXT information from docs.
  + Support single quotes in glade/gtkuibuilder files (lp#1034153).
* Thu Mar 28 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Feb 27 2012 vuntz@opensuse.org
- Update to version 0.50.2:
  + Use --no-translations only if intltool >= 0.50 is available
    (lp#903340).
* Sun Feb  5 2012 zaitor@opensuse.org
- Update to version 0.50.1:
  + Support AM_SILENT_RULES (lp#402516).
  + Improve support for extracting messages from GSettings files
    (lp#922685).
  + Support attribute tag extraction for Glade/GtkBuilder files
    (lp#923841).
  + Start including a ChangeLog in tarballs and provide a NEWS file
    (lp#924386).
* Thu Jan  5 2012 vuntz@opensuse.org
- Fix Source to not use a non-existing URL.
* Thu Dec 22 2011 vuntz@opensuse.org
- Own %%{_datadir}/aclocal to fix build without automake/autoconf.
- Run "make check" in %%check.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 0.50.0:
  + Add support for gsettings gschema.xml files (lp#580526)
  + Let xgettext extract Scheme strings out (lp#790574)
  + Improve handling of quotes in 'intltool-update -m' (lp#806006)
  + Messages are extracted in the order they appear in original
    files now (lp#520986)
  + Other bugs fixed: lp#398576, lp#613003, lp#639857, lp#860192.
* Thu Mar 25 2010 vuntz@opensuse.org
- Update to version 0.41.1:
  + For the detailed list of changes, see:
    https://edge.launchpad.net/intltool/+milestone/0.41.1
  + intltool-update doesn't call intltool-extract correctly on MS
    Windows
  + Support gtkbuilder format for contexts
  + Patch of intltool-update to fix a bug when intltool-update is
    called with a srcdir env var different from "."
  + Support py.in for intltool-update -m
  + intltool-update thinks __import__('<module>') is a translation
  + Fixes in README
* Sun Mar 21 2010 meissner@suse.de
- Update to version 0.41.0:
  + Upstream moved to launchpad
  + Small bugfixes.
  + For details: https://edge.launchpad.net/intltool/trunk/0.41.0
* Sat Mar 14 2009 mboman@suse.de
- Update to version 0.40.6:
  + Update for new usage style and to refer to server files instead
    of oaf
  + Don't hardcode /bin/sh as the shell
  + Add basic support for PACKAGE_BUGREPORT specified by packages
  + Check for at least perl 5.8.1, and print the found version
  + Replace iconv usage with perl's internal Encode::from_to()
  + Quote the grep arguments that use ^
  + Add support for extracting string data from Bioware Aurora Talk
    Table format files, along with the extra metadata associated
    with the strings
  + Redirect grep output to /dev/null
- Don't run autoreconf
* Fri Jan 30 2009 vuntz@novell.com
- Requires gettext-tools instead of gettext-devel. Fix bnc#459088.
- Drop intltool-extract-check-hack.patch: it shouldn't be needed
  anymore since upstream now ships intltool-extract with intltool
  instead of shipping it with each tarballs. So it's always
  available.
* Sun Oct 12 2008 mboman@suse.de
- Update to version 0.40.5:
  + Fixed bug bgo#554280
* Sun Sep 21 2008 mboman@suse.de
- Update to version 0.40.4:
  + Add extract13.desktop to EXTRA_DIST
  + Bugs fixed: bgo#550044, bgo#550727, bgo#549243
  + Require the AM_NLS macro, so USE_NLS gets defined
  + Add a check for gmsgfmt that falls back to $MSGFMT
    This change removes the need for using AM_GLIB_GNU_GETTEXT or
    AM_GNU_GETTEXT for some projects.
* Sun Aug 24 2008 mboman@novell.com
- Update to version 0.40.3:
  * Bugs fixed; bgo#544574, bgo#458794, bgo#544574, bgo#323968,
    bgo#543665, bgo#531894, bgo#536970
  * Add new test cases to EXTRA_DIST and CLEANFILES as appropriate
  * intltoolize.in: Check for symlinks to intltool scripts and remove them
  * intltool-update.in (GenerateHeaders): If running under ActiveState
    Perl then prefix the intltool-extract command with the Perl
    interpreter pathname, as the system() function has no clue about
    Unixish executable scripts indicated by just a hashbang line.
* Fri Jul 18 2008 rodrigo@suse.de
- Use PATCH-*-OPENSUSE, not SUSE, in patch tags
* Wed Jun 11 2008 maw@suse.de
- Update to version 0.40.0:
  + Bugs fixed: bgo#436241, bgo#377573, bgo#489135, bgo#490620,
    bgo#517559, bgo#508320, bgo#516501, bgo#518257, and bgo#509411
- Respin intltool-extract-check-hack.patch.
* Tue Mar  4 2008 maw@suse.de
- Update to version 0.37.1:
  + Bugs fixed: bgo#508320, bgo#516501, bgo#518257, bgo#487818,
    bgo#487666, bgo#499590, bgo#493267, bgo#487817, bgo#499179,
    bgo#491408, bgo#481833, bgo#490845, bgo#488724, bgo#464846,
    bgo#438178, bgo#464846, bgo#464474, bgo#464474, bgo#464121,
    bgo#301364, bgo#311936, bgo#349560, bgo#462312, bgo#449938,
    bgo#411698, bgo#438722, bgo#449938, bgo#430093, bgo#448200,
    bgo#417659, and bgo#413461
  + Note that packages using intltool that also run autoreconf
    (these should be limited to packages that patch
    configure.{in,ac} or Makefile.am files) may need to follow
    autoreconf with intltoolize --force, as some files generated
    by intltool are not compatible across intltool versions
- Respin intltool-extract-check-hack.patch, and annotate it.
* Thu Mar 22 2007 sbrabec@suse.cz
- Worked around bad intltool-extract check.
* Wed Mar 21 2007 maw@suse.de
- Update to version 0.35.5.
  * Don't hardcode fallback path to intltool-extract -- bug #399476
  * Fix mkdir race in inltool-merge.in.in -- bug #400788
  * Update an additional check to use $SRCDIR properly for POTFILES.skip
  - - bug #391892
  * Handle extracting comments from ini-style files -- bug #390271
* Fri Feb 16 2007 maw@suse.de
- Update to version 0.35.4.
  * Fix logic of checking for leftout files in builddir or srcdir
* Thu Dec 21 2006 sreeves@suse.de
- ver 0.35 of intltool is needed for Fate#301648.
  The menu editor we will use is alacarte which requires >=0.35 version
  of intltool. Talked with dobey, jpr and gekker and this rev (0.35.2) was
  approved for submision.
* Fri Jul 21 2006 gekker@suse.de
- Update to version 0.35.0
  * Support for MSGID_BUGS_ADDRESS variable in Makevars and for xgettext
  - - bug #329346 (Dwayne Bailey, Rodney Dawes)
  * Support for po/LINGUAS file being preferred over ALL_LINGUAS variable
  - - bugs #341508 #339770 (Rodney Dawes)
  * Support micro-version when validating version requirements
  - - bug #339627 (Rodney Dawes)
  * Clean up Makefile.in.in to remove useless bits
  - - bug #338817 (Rodney Dawes)
  * Change WARNING to NOTICE for non-UTF-8 po file encodings
  - - bug #331046 (Rodney Dawes)
  * Add MAINTAINERS file
  - - bug #335025 (Danilo Segan)
  * Work around recursive variable resolution in intltool-update
  - - bug #321785 (Danilo Segan)
  * Work around variable stripping in Makefile.in.in substitution
  - - bug #330509 (Rodney Dawes)
- Update to version 0.34.2
  * We require automake >= 1.5 now, so check that we aren't on something older
  - - bug #323282 (Rodney Dawes)
  * Add support for translating DBus service files
  - - bug #322629 (Carlos Garcia Campos)
  * Preserve encoding of XML comments
  - - bug #320721 (Simos Xenitellis)
  * Improve interaction with use of AM_GNU_GETTEXT
  - - bug #312217 (Stepan Kasal)
  * Fix two small issues with srcdir != builddir
    (Stepan Kasal)
  * Remove unused variables from configure.in
  - - bug #312214 (Stepan Kasal)
  * Use $(install_sh) -d instead of $(top_srcdir)/mkinstalldirs
  - - bug #311874 (Stepan Kasal)
  * Don't substitute some variables in the intltool build
  - - bug #315021 (Stepan Kasal)
  * Use POSIX sh syntax for Solaris
  - - bug #322263 (Laszlo Peter)
  * Set the prefix from $0 on win32 systems
    (Tor Lillqvist)
  * Remove unneeded compatibility code for autoconf 2.13
  - - bug #311870 (Stepan Kasal)
  * Remove deprecated INSTOBJEXT variable use
  - - bug #312333 (Stepan Kasal)
  * Remove use of deprecated GENCAT variable
  - - bug #212332 (Stepan Kasal)
  * Use AU_ALIAS instead of AC_DEFUN for autoconf and autoupdate
  - - bug #312334 (Stepan Kasal)
  * Use PACKAGE_NAME instead of AC_PACKAGE_NAME
  - - bug #311523 (Peter Moulder)
* Mon Feb  6 2006 sbrabec@suse.cz
- Fixed Requires (intltool-update requires gettext-devel).
* Fri Feb  3 2006 sbrabec@suse.cz
- Simplified BuildRequires.
- Fixed Requires (intltool-merge requires perl-XML-Parser).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Aug 10 2005 gekker@suse.de
- Update to version 0.34.1
* Mon Aug  1 2005 gekker@suse.de
- Update to version 0.34
* Mon Feb  7 2005 ke@suse.de
- Updated to version 0.33:
  * Various bug fixes, mostly XML related.
* Mon Jan 17 2005 clahey@suse.de
- Updated to version 0.32.1.
* Fri Nov  5 2004 ke@suse.de
- Update to version 0.32:
  * Bug fixes.
  * Deprecate AC_PROG_INTLTOOL for IT_PROG_INTLTOOL.
  * Allow use of either AM_GNU_GETTEXT or AM_GLIB_GNU_GETTEXT and use our
    own Makefile.in.in instead of trying to patch one.
  * Documentation enhancement.
- Drop obsolete patch.
* Thu Jul 15 2004 ke@suse.de
- Update to version 0.31 (from the announcement):
  * Support for C#.
  * New XML merging; entity decoding and encoding is not done anymore
    for XML.
  * Multiple-output XML merging now produces simpler files, and sets
    "xml:lang" only when translation is used
  * Support for passing comments to translators from XML and GConf
    schema files.
  * Bugfixes.
- Enable all tests (stop applying intltool-0.30-selftest.pl.in.patch).
* Wed Feb  4 2004 ke@suse.de
- Update to version 0.30.
- Disable unreliable tests (intltool-0.30-selftest.pl.in.patch; the
  order of attributes isn't static).
* Wed Dec 10 2003 ke@suse.de
- Update to version 0.28; it now depends on the Perl module XML::Parser.
- Adjust neededforbuild: Add perl-XML-Parser and expat.
- intltool-0.28-selftest.pl.in.patch: Disable trouble causing tests.
* Mon Aug 18 2003 sbrabec@suse.cz
- Updated to version 0.27.2.
* Thu Jun 12 2003 sbrabec@suse.cz
- Updated to version 0.26.
- Fixed directory packaging.
* Thu Jan 23 2003 ke@suse.de
- Update to version 0.25; NEWS since 0.21:
  * Support Makefile.in.in from glib-gettextize from glib >= 2.1.5.
  * Strip the hints from POTFILES.in in -M mode.
  * Don't generate .h.h lines in the POTFILES.in for xgettext when the
  input file line is from a known type and also has the [type:
  gettext/..] hint.
  * Fix xml-i18n-tools part to work with new gettext 4.
  * Add a new .theme.in -> .theme rule.
  * gettextize 4.x work.
  * Recognise the "xml:space" attribute and preserve whitespace if set
  to "preserve".
  * GConf schemas handling changes.
  * Use charset.alias if available.
  * Add support for 'default' tags.
  * Added support for translation of descriptions used by ATK in glade
  files.
  * Made schemas extraction code more bulletproof.
  * Force intltool-update to exit if POTFILES.in is not found.
  * Add detection of glade2 files in -m mode.
  * Other bugfixes.
* Thu Sep  5 2002 ro@suse.de
- removed libxml2 requires and from neededforbuild
* Mon Aug 12 2002 ro@suse.de
- fixed permissions of intltool dir
* Thu Jun  6 2002 ke@suse.de
- Update to version 0.21:
  * Add detection of glade2 files in -m mode.
  * Force intltool-update to exit if POTFILES.in is not found.
  * Make schemas extraction code more bulletproof.
  * Add support for translation of descriptions used by ATK in glade
    files.
* Thu May 23 2002 ke@suse.de
- Update to version 0.21:
  * Add support for .schemas files.
  * Some .m4 fixes.
  * Perform variable substitutions when determining package name.
  * Add HOWTO on adding i18n support to an application.
  * Fix Glade XML decoding.
  * Better error reporting.
* Fri May  3 2002 ke@suse.de
- Update to version 0.18: bug fixes, enhancements (e.g., recognize
  directories starting with po- as being translation directories, glade2
  support, take POTFILES.skip and POTFILES.ignore into account), update
  documentation.
* Wed Nov 21 2001 ke@suse.de
- Update to version 0.12.
- Rename package: xml-i18n-tools -> intltool.
- Enable check.
- Numerous bug fixes.
- Heavily improved UTF-8 support.
- Support more input formats (e.g, Dia's .sheet files).
* Wed Aug  8 2001 hhetter@suse.de
- update to version 0.9
* Mon May 28 2001 ke@suse.de
- Apply xml-i18n-tools-prepare.diff to fix typo.
* Fri May 18 2001 ke@suse.de
- Update to version 0.8.4.
* Fri Mar  2 2001 egger@suse.de
- Updated to version 0.8.1.
* Fri Feb 16 2001 hhetter@suse.de
- Updated to version 0.8.
* Thu Feb 15 2001 egger@suse.de
- Updated to version 0.6.
* Tue Jan 23 2001 ke@suse.de
- New package: initial version 0.5.
